aboutsummaryrefslogtreecommitdiff
path: root/backends/fs/morphos
diff options
context:
space:
mode:
Diffstat (limited to 'backends/fs/morphos')
-rw-r--r--backends/fs/morphos/abox-fs-factory.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/backends/fs/morphos/abox-fs-factory.h b/backends/fs/morphos/abox-fs-factory.h
index 1adbd1475a..0a53822447 100644
--- a/backends/fs/morphos/abox-fs-factory.h
+++ b/backends/fs/morphos/abox-fs-factory.h
@@ -26,14 +26,14 @@
#define ABOX_FILESYSTEM_FACTORY_H
#include "common/singleton.h"
-#include "backends/fs/abstract-fs-factory.h"
+#include "backends/fs/fs-factory.h"
/**
* Creates ABoxFilesystemNode objects.
*
* Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
*/
-class ABoxFilesystemFactory : public AbstractFilesystemFactory, public Common::Singleton<ABoxFilesystemFactory> {
+class ABoxFilesystemFactory : public FilesystemFactory, public Common::Singleton<ABoxFilesystemFactory> {
public:
typedef Common::String String;
@@ -26,14 +26,14 @@
* Creates ABoxFilesystemNode objects.
*
- * Parts of this class are documented in the base interface class, AbstractFilesystemFactory.
+ * Parts of this class are documented in the base interface class, FilesystemFactory.
*/